****************SETUP THE FIRM LEVEL DATA FOR NIGERIA

*****NOTE: If the relevant files are not in the "C:\Nigeria Wages\" directory use search/replace to point to the correct directory

***********Basic Setup of the 2007 Data

****** Load Data 
****  PUT THE DATA FROM the www.enterprisesurveys.org website into the "C:\Nigeria Wages\" directory
****  Correct the name of the dataset in the use command below

clear all
set mem 20m

use "C:\Nigeria Wages\Nigeria_2007_2387_RAW_ALL_WEIGHTED.dta", clear


********************BASIC DATA

****Country Name

gen countryn="Nigeria 2007" 
label var countryn "Country Name"

****Year of Productivity Data

generate yearsurv=2007
label var yearsurv "Year - Year - Year of Survey"

***Survey Type

gen weight=weight_locsec
label var weight "Weight"

********************ENTERPRISE CHARACTERISTICS

****Age

generate age=yearsurv-b4c if b4c>1696
label var age "Age - Years - Age of estabishment"

generate lage=log(age)
label var lage "Age - Years (Log) - Log of Age of estabishment"

gen dmag0005=(age>=0&age<5) if age~=.
label var dmag0005 "Age - Dummy - Less that five years old"

gen dmag0510=(age>=5&age<10) if age~=.
label var dmag0510 "Age - Dummy - Between five and ten years old"

gen dmag1099=(age>=10&age<10000) if age~=.
label var dmag1099 "Age - Dummy - Ten years and older"


****Exports

egen chk=rsum(c6a c6b c6c)

egen exportsh=rsum(c6b c6c)
replace exportsh=. if chk~=100
label var exportsh "Exports - Percent - Exports as percent of sales in 2007"

generate dmexport=exportsh>0
replace dmexport=. if chk~=100
label var dmexport "Exports - Dummy - Exports in 2007"

drop chk


****Ownership

replace b2a=0 if b2a==.|b2a<0
replace b2b=0 if b2b==.|b2b<0
replace b2c=0 if b2c==.|b2c<0
replace b2d=0 if b2d==.|b2d<0

egen chk=rsum(b2a b2b b2c b2d)

gen ownforsh=b2b if chk==100
label var ownforsh "Foreign Ownership - Percent - Percent foreign owned"

gen dmownafor=ownforsh>0
replace dmownafor=. if chk~=100
label var dmownafor "Ownership - Dummy - Any foreign ownership"

gen dmownfor=dmownafor
replace dmownfor=0 if ownforsh<50&chk==100
label var dmownfor "Ownership - Dummy - Main owners is foreign"

drop chk

****Training

gen dmtrain=2-j8b if j8b==1|j8b==2
label var dmtrain "Training - Dummy - Firm has training program"

gen trainsh=0 if dmtrain==0
replace trainsh=j8c1 if j8c1>=0&dmtrain==1
label var trainsh "Training - Percent - Percent of production workers that are trained"

gen trainshnonp=0 if dmtrain==0
replace trainshnonp=j8c2 if j8c2>=0&dmtrain==1
label var trainshnonp "Training - Percent - Percent of non-production workers that are trained"

******Union

gen percunion=j6b if j6b>=0
label var percunion "Percentage unionized"

********************SECTOR

****ISIC codes for main product

gen ISIC=c3a2 if c3a2>=1500&c3a2<=7499
label var ISIC "Sector - Code - ISIC Code"

****Big Sector based primarily on sector from ISIC codes replaced with sector when ISIC is missing

gen dmbsmanf=(ISIC>=1500)&(ISIC<=3799) if ISIC~=.
replace dmbsmanf=industry<=10 if industry~=.&ISIC==.
label var dmbsmanf "Big Sector - Dummy - Manufacturing Sector (based primarily upon ISIC)"

gen dmbsret=(ISIC>=5000)&(ISIC<=5299) if ISIC~=.
replace dmbsret=industry==11 if industry~=.&ISIC==.
label var dmbsret "Big Sector - Dummy - Retail Sector based upon ISIC (based primarily upon ISIC)"

gen dmbsserv=(ISIC>=3800)&(ISIC<=7300) if ISIC~=.
replace dmbsserv=0 if (ISIC>=5000)&(ISIC<=5299)&ISIC~=.
replace dmbsserv=industry>=12 if industry~=.&ISIC==.
label var dmbsserv "Big Sector - Dummy - Service Sector based upon ISIC (based primarily upon ISIC)"

****Small sector based primarily on ISIC codes replaced with sector when ISIC is missing and when the codes line up neatly with our ISIC divisions

gen dmsctextiles=ISIC>=1700&ISIC<=1729 if ISIC~=.
replace dmsctextiles=(industry==3) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmsctextiles "Dummy - Sector - Textiles (based primarily upon ISIC)"

gen dmscgarments=ISIC>=1730&ISIC<2000 if ISIC~=.
replace dmscgarments=industry==2 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscgarments "Dummy - Sector - Leather and Garments "

gen dmscagro=ISIC>=1500&ISIC<=1600 if ISIC~=.
replace dmscagro=(industry==1) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscagro "Dummy - Sector - Agroindustry"

gen dmscchem=(ISIC>=2300)&(ISIC<=2499) if ISIC~=.
replace dmscchem=(industry==5) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscchem "Sector - Dummy - Chemicals"

gen dmscconst=(ISIC>=2690)&(ISIC<=2699) if ISIC~=.
replace dmscconst=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscconst "Sector - Dummy - Construction Materials"

gen dmscfurn=(ISIC>=2000)&(ISIC<=2099)|ISIC==3610 if ISIC~=.
replace dmscfurn=(industry==8) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscfurn "Sector - Dummy - Furniture and wood"

gen dmscmetal=(ISIC>=2700)&(ISIC<=2899) if ISIC~=.
replace dmscmetal=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscmetal "Sector - Dummy - Metals and Metal Products"

gen dmscpaper=(ISIC>=2100)&(ISIC<=2299) if ISIC~=.
replace dmscpaper=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscpaper "Sector - Dummy - Paper, Printing, Publishing"

gen dmscplastic=(ISIC>=2500)&(ISIC<=2599) if ISIC~=.
replace dmscplastic=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscplastic "Sector - Dummy - Plastic"

gen dmscmach=(ISIC>=2900)&(ISIC<=2999) if ISIC~=.
replace dmscmach=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscmach "Sector - Dummy - Machinery"

gen dmscelec=(ISIC>=3100)&(ISIC<3399) if ISIC~=.
replace dmscelec=(industry==6) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscelec "Sector - Dummy - Electrical Equipment, Televisions and Scientific Equipment"

gen dmscmotor=(ISIC>=3400)&(ISIC<=3600) if ISIC~=.
replace dmscmotor=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscmotor "Sector - Dummy - Motor Vehicles and parts, transportation equipment"

gen dmscoth=ISIC==3699|ISIC==2610|ISIC==2600|ISIC==3000|ISIC==3691|ISIC==3720|ISIC==3693|ISIC==3710|ISIC==3720|ISIC==3692|ISIC==3694 if ISIC~=.
replace dmscoth=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscoth "Sector - Dummy - Other manufacturing (incl office equipment, glass products"

gen dmsctrad=(ISIC>=5000)&(ISIC<=5499) if ISIC~=.
replace dmsctrad=(industry==11) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmsctrad "Sector - Dummy - Retail Trade"

gen dmsctour=(ISIC>=5500)&(ISIC<=5599) if ISIC~=.
replace dmsctour=(industry==14) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmsctour "Sector - Dummy - Hotels and Restaurants"

gen dmscserv=(ISIC>=6500)&(ISIC<=7499) if ISIC~=.
replace dmscserv=(industry==12|industry==15) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscserv "Sector - Dummy - Other Services (non-tourism, non-trade, non-transportation)"

gen dmsccnstr=(ISIC>=4500)&(ISIC<=4599) if ISIC~=.
replace dmsccnstr=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmsccnstr "Sector - Dummy - Construction"

gen dmsctrans=(ISIC>=6000)&(ISIC<=6499) if ISIC~=.
replace dmsctrans=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmsctrans "Sector - Dummy - Transporation"

********************ENTERPRISE CHARACTERISTICS

****Country Level Variables

gen ccdefl=(192.215377239075/160.77)
label var ccdefl "Country control - Number - GDP Deflator (one year lagged from survey)"

gen ccdeflm2=(111.195534810793/160.77)
label var ccdeflm2 "Country control - Number - GDP Deflator(three years lagged from survey)"

gen ccdefl05=(160.77/160.77)
label var ccdefl05 "Country control - Number - GDP Deflator(three years lagged from survey)"

gen ccdefl09=(213.581327593652/160.77)
label var ccdefl09 "Country control - Number - GDP Deflator(three years lagged from survey)"

gen ccexch=128.651666666667
label var ccexch "Country control - Number - Exchange Rate (one year lagged from survey)"

gen ccexchm2=129.22235
label var ccexchm2 "Country control - Number - Exchange Rate(three years lagged from survey)"

gen ccexch05=131.27
label var ccexch "Country control - Number - Exchange Rate (one year lagged from survey)"

gen ccexch09=148.901741666667
label var ccexch "Country control - Number - Exchange Rate (one year lagged from survey)"

*******************Productivity

****Workers - Number and Growth Rate

replace j2a=. if j2a<0
replace j2c=. if j2c<0
replace j3a=. if j3a<0
replace j3c=. if j3c<0
replace j4a=. if j4a<0

generate workpermfull=j2a
label var workpermfull "Workers - Number - Permanent fulltime workers"

generate worktempfull=j3a*(j3c/12) if j3a>0
replace worktempfull=0 if j3a==0
label var worktempfull "Workers - Number - Average number of temporary fulltime workers"

generate prdwork=workpermfull+worktempfull
replace prdwork=j2a+j4a if sampsize==.
label var prdwork "Productivity - Number - # of Workers (no part-time)"

drop workpermfull worktempfull

****Average wages

gen wgavprodskus=12*((ng_j2d1s)*(ccdefl05/ccdefl)) if ng_j2d1s>=0
label var wgavprodskus "Wages - US$ - Average annual wages for skilled production workers in 2005 Naira"

gen wgavprodunus=12*((ng_j2d1u)*(ccdefl05/ccdefl)) if ng_j2d1u>=0
label var wgavprodunus "Wages - US$ - Average annual wages for unskilled production workers in 2005 Naira"

**********************Reticence

gen dmretperstax=2-ng_m6a if ng_m6a>0
label var dmretperstax "Reticence - Dummy - Paid less in personal taxes than should have under the law"

gen dmretcorptax=2-ng_m6b if ng_m6b>0
label var dmretcorptax "Reticence - Dummy - Paid less in business taxes than should have under the law"

gen dmretmisstatejob=2-ng_m6c if ng_m6c>0
label var dmretmisstatejob "Reticence - Dummy - Misstatement on a job application"

gen dmnonrettel=2-ng_m6d if ng_m6d>0
label var dmnonrettel "Reticence - Dummy - (NON SENSITIVE) Used telephone for personal business"

gen dmretpromemp=2-ng_m6e if ng_m6e>0
label var dmretpromemp "Reticence - Dummy - Inappropriately promoted an employee for personal reasons"

gen dmretcheatclients=2-ng_m6f if ng_m6f>0
label var dmretcheatclients "Reticence - Dummy - Ever not given your suppliers or clients what was due them"

gen dmnonretlied=2-ng_m6g if ng_m6g>0
label var dmnonretlied "Reticence - Dummy - (NON SENSITIVE) Lied for own self-interest"

gen dmretchireemp=2-ng_m6h if ng_m6h>0
label var dmretchireemp "Reticence - Dummy - Inappropriately hired an employee for personal reasons"

gen dmnonretlate=2-ng_m6i if ng_m6i>0
label var dmnonretlate "Reticence - Dummy - (NON SENSITIVE) Been purposely late for work"

gen dmretcfireemp=2-ng_m6j if ng_m6j>0
label var dmretcfireemp "Reticence - Dummy - Inappropriately fired an employee for personal reasons"

gen retcount=7-dmretperstax-dmretcorptax-dmretmisstatejob-dmretpromemp-dmretcheatclients-dmretchireemp-dmretcfireemp
label var retcount "Reticence - Number - Number of  Nos to reticence questions"

gen retcount10=10-dmretperstax-dmretcorptax-dmretmisstatejob-dmretpromemp-dmretcheatclients-dmretchireemp-dmretcfireemp-dmnonretlate-dmnonretlied-dmnonrettel
label var retcount10 "Reticence - Number - Number of  Nos to reticence questions (all ten questions)"

gen dmreticent=retcount==7 if retcount~=.
label var dmreticent "Reticence - Dummy - Firm is reticent"

gen dmreticent10=retcount10==10 if retcount~=.
label var dmreticent10 "Reticence - Dummy - Firm is reticent (10 questions)"

gen dmretnotund=AV3==1
label var dmretnotund "Reticent - Dummy - Did not understand"

gen dmreticentgood=dmreticent if dmretnotund==0
label var dmreticentgood "Reticence - Dummy - Firm is reticent (NA if did not understand)"

gen dmreticent10good=dmreticent10 if dmretnotund==0
label var dmreticent10good "Reticence - Dummy - Firm is reticent (10 questions, NA if did not understand)"

gen retcountgood=retcount if dmretnotund==0
label var retcountgood "Reticence - Number - Number of  Nos to reticence questions (NA if did not understand)"

gen retcount10good=retcount10 if dmretnotund==0
label var retcount10good "Reticence - Number - Number of  Nos to reticence questions (NA if did not understand)"

sort intcode
by intcode: egen ctdmreticentgood=count(dmreticentgood)
by intcode: egen avdmreticentgood=mean(dmreticentgood)

sort intcode
by intcode: egen ctdmreticent10good=count(dmreticent10good)
by intcode: egen avdmreticent10good=mean(dmreticent10good)

sort intcode
by intcode: egen ctretcount=count(retcount)
by intcode: egen avretcount=mean(retcount)

sort intcode
by intcode: egen ctretcountgood=count(retcountgood)
by intcode: egen avretcountgood=mean(retcountgood)

sort intcode
by intcode: egen ctretcount10good=count(retcount10good)
by intcode: egen avretcount10good=mean(retcount10good)

gen avdmreticentgoodloo=(ctdmreticentgood/(ctdmreticentgood-1))*avdmreticentgood-(1/(ctdmreticentgood-1))*dmreticentgood
label var avdmreticentgoodloo "Reticence -- average of reticence dummies for interviewer (leave-one-out)"

gen avdmreticent10goodloo=(ctdmreticent10good/(ctdmreticent10good-1))*avdmreticent10good-(1/(ctdmreticent10good-1))*dmreticent10good
label var avdmreticent10goodloo "Reticence -- average of reticence dummies for interviewer (10 questions, leave-one-out)"

gen avretcountgoodloo=(ctretcountgood/(ctretcountgood-1))*avretcountgood-(1/(ctretcountgood-1))*retcountgood
label var avretcountgoodloo "Reticence -- average of reticence count  for interviewer (leave-one-out)"

gen avretcount10goodloo=(ctretcount10good/(ctretcount10good-1))*avretcount10good-(1/(ctretcount10good-1))*retcount10good
label var avretcount10goodloo "Reticence -- average of reticence count  for interviewer (leave-one-out)"

gen avretcountloo=(ctretcount/(ctretcount-1))*avretcount-(1/(ctretcount-1))*retcount
label var avretcountloo "Reticence -- average of reticence count  for interviewer (leave-one-out)"


drop ct* 
drop avdmreticentgood avdmreticent10good avretcount avretcountgood avretcount10good

**********************Control Variables

gen dmmngmal=ng_b3k1==1 if ng_b3k==2&ng_b3k1>0
replace dmmngmal=ng_b3f==1 if ng_b3k==1&ng_b3f>0
label var dmmngmal "Manager -- Dummy -- Manager is male"

gen dmmngage0030=(ng_b3k2==1) if ng_b3k==2&ng_b3k2>0
replace dmmngage0030=(ng_b3h==1) if ng_b3k==1&ng_b3h>0
label var dmmngage0030 "Manager - Dummy - Manager younger than 30"

gen dmmngage3145=(ng_b3k2==2) if ng_b3k==2&ng_b3k2>0
replace dmmngage3145=(ng_b3h==2) if ng_b3k==1&ng_b3h>0
label var dmmngage3145 "Manager - Dummy - Manager between 31 and 45"

gen dmmngage4655=(ng_b3k2==3) if ng_b3k==2&ng_b3k2>0
replace dmmngage4655=(ng_b3h==3) if ng_b3k==1&ng_b3h>0
label var dmmngage4655 "Manager - Dummy - Manager between 46 and 55"

gen dmmngage5600=(ng_b3k2==4) if ng_b3k==2&ng_b3k2>0
replace dmmngage5600=(ng_b3h==4) if ng_b3k==1&ng_b3h>0
label var dmmngage5600 "Manager - Dummy - Manager older than 55"

gen dmmngedsec=(ng_b3k3>=4&ng_b3k3<=6) if ng_b3k==2&ng_b3k3>0
replace dmmngedsec=(ng_b3i>=4&ng_b3i<=6) if ng_b3k==1&ng_b3i>0
label var dmmngedsec "Manager - Dummy - Manager has secondary education"

gen dmmngedtert=(ng_b3k3>=7&ng_b3k3<=12) if ng_b3k==2&ng_b3k3>0
replace dmmngedtert=(ng_b3i>=7&ng_b3i<=12)  if ng_b3k==1&ng_b3i>0
label var dmmngedtert "Manager - Dummy - Manager has secondary education"

gen dmsouth=1 if reg==1
replace dmsouth=0 if  reg==2
replace dmsouth=0 if reg==3
replace dmsouth=0 if reg==4
replace dmsouth=1 if reg==5
replace dmsouth=1 if reg==6
replace dmsouth=0 if reg==7
replace dmsouth=0 if reg==8
replace dmsouth=1 if reg==9
replace dmsouth=1 if reg==10
replace dmsouth=0 if reg==11
label var dmsouth "Region -- Dummy -- Southern Province"

gen region=reg
label var region "Region"

gen size=sampsize
label var size "Firm Size"

gen dmaszmid=size==2
label var dmaszmid "Firm Size -- Dummy -- Medium"

gen dmaszlar=size==3
label var dmaszlar "Firm Size -- Dummy -- Large"

replace intcode=intcode+2007000

keep idquest m2 countryn yearsurv weight dmbs* dmsc* dmownfor dmexport lage prdwork wgavprodskus wgavprodunus dmreticent retcount dmretnotund dmreticentgood dmreticent10good retcountgood avdmreticentgoodloo avdmreticent10goodloo avretcountgoodloo dmmngmal dmmngage0030 dmmngage3145 dmmngage4655 dmmngage5600 dmmngedsec dmmngedtert dmsouth region dmaszmid dmaszlar percunion region  retcount* avretcount* industry reg screensi zone multi dmret* dmnonret* intcode

save "C:\Nigeria Wages\Nigeria Wages Firm Level Data TEMP.dta", replace


*****************Basic setup for the 2009 firm-level data

****** Load Data

clear all
set mem 20m

use "C:\Nigeria Wages\Nigeria20009_weighted_widcts.dta", clear


********************BASIC DATA

****Country Name

gen countryn="Nigeria 2009" 
label var countryn "Country Name"

****Year of Productivity Data

generate yearsurv=2009
label var yearsurv "Year - Year - Year of Survey"

***Survey Type

gen weight=weight_est
label var weight "Weight"

********************ENTERPRISE CHARACTERISTICS

****Age

generate age=yearsurv-b4c if b4c>1696
label var age "Age - Years - Age of estabishment"

generate lage=log(age)
label var lage "Age - Years (Log) - Log of Age of estabishment"

gen dmag0005=(age>=0&age<5) if age~=.
label var dmag0005 "Age - Dummy - Less that five years old"

gen dmag0510=(age>=5&age<10) if age~=.
label var dmag0510 "Age - Dummy - Between five and ten years old"

gen dmag1099=(age>=10&age<10000) if age~=.
label var dmag1099 "Age - Dummy - Ten years and older"


****Exports

egen chk=rsum(c6a c6b c6c)

egen exportsh=rsum(c6b c6c)
replace exportsh=. if chk~=100
label var exportsh "Exports - Percent - Exports as percent of sales in 2007"

generate dmexport=exportsh>0
replace dmexport=. if chk~=100
label var dmexport "Exports - Dummy - Exports in 2007"

drop chk


****Ownership

replace b2a=0 if b2a==.|b2a<0
replace b2b=0 if b2b==.|b2b<0
replace b2c=0 if b2c==.|b2c<0
replace b2d=0 if b2d==.|b2d<0

egen chk=rsum(b2a b2b b2c b2d)

gen ownforsh=b2b if chk==100
label var ownforsh "Foreign Ownership - Percent - Percent foreign owned"

gen dmownafor=ownforsh>0
replace dmownafor=. if chk~=100
label var dmownafor "Ownership - Dummy - Any foreign ownership"

gen dmownfor=dmownafor
replace dmownfor=0 if ownforsh<50&chk==100
label var dmownfor "Ownership - Dummy - Main owners is foreign"

drop chk

******Union

gen percunion=j6b if j6b>=0
label var percunion "Percentage unionized"

********************SECTOR

****ISIC codes for main product

gen ISIC=c3a2 if c3a2>=1500&c3a2<=7499
label var ISIC "Sector - Code - ISIC Code"

****Big Sector based primarily on sector from ISIC codes replaced with sector when ISIC is missing

gen dmbsmanf=(ISIC>=1500)&(ISIC<=3799) if ISIC~=.
replace dmbsmanf=industry<=10 if industry~=.&ISIC==.
label var dmbsmanf "Big Sector - Dummy - Manufacturing Sector (based primarily upon ISIC)"

gen dmbsret=(ISIC>=5000)&(ISIC<=5299) if ISIC~=.
replace dmbsret=industry==11 if industry~=.&ISIC==.
label var dmbsret "Big Sector - Dummy - Retail Sector based upon ISIC (based primarily upon ISIC)"

gen dmbsserv=(ISIC>=3800)&(ISIC<=7300) if ISIC~=.
replace dmbsserv=0 if (ISIC>=5000)&(ISIC<=5299)&ISIC~=.
replace dmbsserv=industry>=12 if industry~=.&ISIC==.
label var dmbsserv "Big Sector - Dummy - Service Sector based upon ISIC (based primarily upon ISIC)"

****Small sector based primarily on ISIC codes replaced with sector when ISIC is missing and when the codes line up neatly with our ISIC divisions

gen dmsctextiles=ISIC>=1700&ISIC<=1729 if ISIC~=.
replace dmsctextiles=(industry==3) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmsctextiles "Dummy - Sector - Textiles (based primarily upon ISIC)"

gen dmscgarments=ISIC>=1730&ISIC<2000 if ISIC~=.
replace dmscgarments=industry==2 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscgarments "Dummy - Sector - Leather and Garments "

gen dmscagro=ISIC>=1500&ISIC<=1600 if ISIC~=.
replace dmscagro=(industry==1) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscagro "Dummy - Sector - Agroindustry"

gen dmscchem=(ISIC>=2300)&(ISIC<=2499) if ISIC~=.
replace dmscchem=(industry==5) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscchem "Sector - Dummy - Chemicals"

gen dmscconst=(ISIC>=2690)&(ISIC<=2699) if ISIC~=.
replace dmscconst=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscconst "Sector - Dummy - Construction Materials"

gen dmscfurn=(ISIC>=2000)&(ISIC<=2099)|ISIC==3610 if ISIC~=.
replace dmscfurn=(industry==8) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscfurn "Sector - Dummy - Furniture and wood"

gen dmscmetal=(ISIC>=2700)&(ISIC<=2899) if ISIC~=.
replace dmscmetal=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscmetal "Sector - Dummy - Metals and Metal Products"

gen dmscpaper=(ISIC>=2100)&(ISIC<=2299) if ISIC~=.
replace dmscpaper=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscpaper "Sector - Dummy - Paper, Printing, Publishing"

gen dmscplastic=(ISIC>=2500)&(ISIC<=2599) if ISIC~=.
replace dmscplastic=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscplastic "Sector - Dummy - Plastic"

gen dmscmach=(ISIC>=2900)&(ISIC<=2999) if ISIC~=.
replace dmscmach=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscmach "Sector - Dummy - Machinery"

gen dmscelec=(ISIC>=3100)&(ISIC<3399) if ISIC~=.
replace dmscelec=(industry==6) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscelec "Sector - Dummy - Electrical Equipment, Televisions and Scientific Equipment"

gen dmscmotor=(ISIC>=3400)&(ISIC<=3600) if ISIC~=.
replace dmscmotor=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscmotor "Sector - Dummy - Motor Vehicles and parts, transportation equipment"

gen dmscoth=ISIC==3699|ISIC==2610|ISIC==2600|ISIC==3000|ISIC==3691|ISIC==3720|ISIC==3693|ISIC==3710|ISIC==3720|ISIC==3692|ISIC==3694 if ISIC~=.
replace dmscoth=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscoth "Sector - Dummy - Other manufacturing (incl office equipment, glass products"

gen dmsctrad=(ISIC>=5000)&(ISIC<=5499) if ISIC~=.
replace dmsctrad=(industry==11) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmsctrad "Sector - Dummy - Retail Trade"

gen dmsctour=(ISIC>=5500)&(ISIC<=5599) if ISIC~=.
replace dmsctour=(industry==14) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmsctour "Sector - Dummy - Hotels and Restaurants"

gen dmscserv=(ISIC>=6500)&(ISIC<=7499) if ISIC~=.
replace dmscserv=(industry==12|industry==15) if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmscserv "Sector - Dummy - Other Services (non-tourism, non-trade, non-transportation)"

gen dmsccnstr=(ISIC>=4500)&(ISIC<=4599) if ISIC~=.
replace dmsccnstr=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmsccnstr "Sector - Dummy - Construction"

gen dmsctrans=(ISIC>=6000)&(ISIC<=6499) if ISIC~=.
replace dmsctrans=0 if industry~=.&ISIC==.&industry~=13&industry~=10
label var dmsctrans "Sector - Dummy - Transporation"
 
********************ENTERPRISE CHARACTERISTICS

*******************Country Level Variables

gen ccdefl=(223.55/160.77)
label var ccdefl "Country control - Number - GDP Deflator (one year lagged from survey)"

gen ccdeflm2=(160.77/160.77)
label var ccdeflm2 "Country control - Number - GDP Deflator(three years lagged from survey)"

gen ccdefl05=(160.77/160.77)
label var ccdefl05 "Country control - Number - GDP Deflator(three years lagged from survey)"

gen ccexch=118.55
label var ccexch "Country control - Number - Exchange Rate (one year lagged from survey)"

gen ccexchm2=131.27
label var ccexchm2 "Country control - Number - Exchange Rate(three years lagged from survey)"

gen ccexch05=131.27
label var ccexch "Country control - Number - Exchange Rate (one year lagged from survey)"

*******************Productivity

****Workers - Number and Growth Rate

replace j2a=. if j2a<0
replace j2c=. if j2c<0
replace j3a=. if j3a<0
replace j3c=. if j3c<0
replace j4a=. if j4a<0

generate workpermfull=j2a
label var workpermfull "Workers - Number - Permanent fulltime workers"

generate worktempfull=j3a*(j3c/12) if j3a>0
replace worktempfull=0 if j3a==0
label var worktempfull "Workers - Number - Average number of temporary fulltime workers"

generate prdwork=workpermfull+worktempfull
replace prdwork=j2a+j4a if sampsize==.
label var prdwork "Productivity - Number - # of Workers (no part-time)"

drop workpermfull worktempfull

*****Average wages

gen wgavprodskus=12*((ng_j2d1s)*(ccdefl05/ccdefl)) if ng_j2d1s>=0
label var wgavprodskus "Wages - US$ - Average annual wages for skilled production workers in 2005 Naira"

gen wgavprodunus=12*((ng_j2d1u)*(ccdefl05/ccdefl)) if ng_j2d1u>=0
label var wgavprodunus "Wages - US$ - Average annual wages for unskilled production workers in 2005 Naira"

**********************Reticence

gen dmretperstax=2-ng_m6a if ng_m6a>0
label var dmretperstax "Reticence - Dummy - Paid less in personal taxes than should have under the law"

gen dmretcorptax=2-ng_m6b if ng_m6b>0
label var dmretcorptax "Reticence - Dummy - Paid less in business taxes than should have under the law"

gen dmretmisstatejob=2-ng_m6c if ng_m6c>0
label var dmretmisstatejob "Reticence - Dummy - Misstatement on a job application"

gen dmnonrettel=2-ng_m6d if ng_m6d>0
label var dmnonrettel "Reticence - Dummy - (NON SENSITIVE) Used telephone for personal business"

gen dmretpromemp=2-ng_m6e if ng_m6e>0
label var dmretpromemp "Reticence - Dummy - Inappropriately promoted an employee for personal reasons"

gen dmretcheatclients=2-ng_m6f if ng_m6f>0
label var dmretcheatclients "Reticence - Dummy - Ever not given your suppliers or clients what was due them"

gen dmnonretlied=2-ng_m6g if ng_m6g>0
label var dmnonretlied "Reticence - Dummy - (NON SENSITIVE) Lied for own self-interest"

gen dmretchireemp=2-ng_m6h if ng_m6h>0
label var dmretchireemp "Reticence - Dummy - Inappropriately hired an employee for personal reasons"

gen dmnonretlate=2-ng_m6i if ng_m6i>0
label var dmnonretlate "Reticence - Dummy - (NON SENSITIVE) Been purposely late for work"

gen dmretcfireemp=2-ng_m6j if ng_m6j>0
label var dmretcfireemp "Reticence - Dummy - Inappropriately fired an employee for personal reasons"

gen retcount=7-dmretperstax-dmretcorptax-dmretmisstatejob-dmretpromemp-dmretcheatclients-dmretchireemp-dmretcfireemp
label var retcount "Reticence - Number - Number of  Nos to reticence questions"

gen retcount10=10-dmretperstax-dmretcorptax-dmretmisstatejob-dmretpromemp-dmretcheatclients-dmretchireemp-dmretcfireemp-dmnonretlate-dmnonretlied-dmnonrettel
label var retcount10 "Reticence - Number - Number of  Nos to reticence questions (all ten questions)"

gen dmreticent=retcount==7 if retcount~=.
label var dmreticent "Reticence - Dummy - Firm is reticent"

gen dmreticent10=retcount10==10 if retcount~=.
label var dmreticent10 "Reticence - Dummy - Firm is reticent (10 questions)"

gen dmretnotund=av3==1
label var dmretnotund "Reticent - Dummy - Did not understand"

gen dmreticentgood=dmreticent if dmretnotund==0
label var dmreticentgood "Reticence - Dummy - Firm is reticent (NA if did not understand)"

gen dmreticent10good=dmreticent10 if dmretnotund==0
label var dmreticent10good "Reticence - Dummy - Firm is reticent (10 questions, NA if did not understand)"

gen retcountgood=retcount if dmretnotund==0
label var retcountgood "Reticence - Number - Number of  Nos to reticence questions (NA if did not understand)"

gen retcount10good=retcount10 if dmretnotund==0
label var retcount10good "Reticence - Number - Number of  Nos to reticence questions (NA if did not understand)"

sort intcode
by intcode: egen ctdmreticentgood=count(dmreticentgood)
by intcode: egen avdmreticentgood=mean(dmreticentgood)

sort intcode
by intcode: egen ctdmreticent10good=count(dmreticent10good)
by intcode: egen avdmreticent10good=mean(dmreticent10good)

sort intcode
by intcode: egen ctretcount=count(retcount)
by intcode: egen avretcount=mean(retcount)

sort intcode
by intcode: egen ctretcountgood=count(retcountgood)
by intcode: egen avretcountgood=mean(retcountgood)

sort intcode
by intcode: egen ctretcount10good=count(retcount10good)
by intcode: egen avretcount10good=mean(retcount10good)

gen avdmreticentgoodloo=(ctdmreticentgood/(ctdmreticentgood-1))*avdmreticentgood-(1/(ctdmreticentgood-1))*dmreticentgood
label var avdmreticentgoodloo "Reticence -- average of reticence dummies for interviewer (leave-one-out)"

gen avdmreticent10goodloo=(ctdmreticent10good/(ctdmreticent10good-1))*avdmreticent10good-(1/(ctdmreticent10good-1))*dmreticent10good
label var avdmreticent10goodloo "Reticence -- average of reticence dummies for interviewer (10 questions, leave-one-out)"

gen avretcountgoodloo=(ctretcountgood/(ctretcountgood-1))*avretcountgood-(1/(ctretcountgood-1))*retcountgood
label var avretcountgoodloo "Reticence -- average of reticence count  for interviewer (leave-one-out)"

gen avretcount10goodloo=(ctretcount10good/(ctretcount10good-1))*avretcount10good-(1/(ctretcount10good-1))*retcount10good
label var avretcount10goodloo "Reticence -- average of reticence count  for interviewer (leave-one-out)"

gen avretcountloo=(ctretcount/(ctretcount-1))*avretcount-(1/(ctretcount-1))*retcount
label var avretcountloo "Reticence -- average of reticence count  for interviewer (leave-one-out)"


drop ct* 
drop avdmreticentgood avdmreticent10good avretcount avretcountgood avretcount10good

**********************Control Variables

gen dmmngmal=ng_b3k1==1 if ng_b3k==2&ng_b3k1>0
replace dmmngmal=ng_b3f==1 if ng_b3k==1&ng_b3f>0
label var dmmngmal "Manager -- Dummy -- Manager is male"

gen dmmngage0030=(ng_b3k2==1) if ng_b3k==2&ng_b3k2>0
replace dmmngage0030=(ng_b3h==1) if ng_b3k==1&ng_b3h>0
label var dmmngage0030 "Manager - Dummy - Manager younger than 30"

gen dmmngage3145=(ng_b3k2==2) if ng_b3k==2&ng_b3k2>0
replace dmmngage3145=(ng_b3h==2) if ng_b3k==1&ng_b3h>0
label var dmmngage3145 "Manager - Dummy - Manager between 31 and 45"

gen dmmngage4655=(ng_b3k2==3) if ng_b3k==2&ng_b3k2>0
replace dmmngage4655=(ng_b3h==3) if ng_b3k==1&ng_b3h>0
label var dmmngage4655 "Manager - Dummy - Manager between 46 and 55"

gen dmmngage5600=(ng_b3k2==4) if ng_b3k==2&ng_b3k2>0
replace dmmngage5600=(ng_b3h==4) if ng_b3k==1&ng_b3h>0
label var dmmngage5600 "Manager - Dummy - Manager older than 55"

gen dmmngedsec=(ng_b3k3>=4&ng_b3k3<=6) if ng_b3k==2&ng_b3k3>0
replace dmmngedsec=(ng_b3i>=4&ng_b3i<=6) if ng_b3k==1&ng_b3i>0
label var dmmngedsec "Manager - Dummy - Manager has secondary education"

gen dmmngedtert=(ng_b3k3>=7&ng_b3k3<=12) if ng_b3k==2&ng_b3k3>0
replace dmmngedtert=(ng_b3i>=7&ng_b3i<=12)  if ng_b3k==1&ng_b3i>0
label var dmmngedtert "Manager - Dummy - Manager has secondary education"

gen dmsouth=0 if reg==1
replace dmsouth=1 if  reg==2
replace dmsouth=1 if  reg==3
replace dmsouth=1 if  reg==4
replace dmsouth=0 if  reg==5
replace dmsouth=1 if  reg==6
replace dmsouth=1 if  reg==7
replace dmsouth=1 if  reg==8
replace dmsouth=1 if  reg==9
replace dmsouth=0 if  reg==10
replace dmsouth=1 if  reg==11
replace dmsouth=0 if  reg==12
replace dmsouth=0 if  reg==13
replace dmsouth=0 if  reg==14
replace dmsouth=1 if  reg==15
replace dmsouth=0 if  reg==16
replace dmsouth=0 if  reg==17
replace dmsouth=0 if  reg==18
replace dmsouth=1 if  reg==19
replace dmsouth=1 if  reg==20
replace dmsouth=0 if  reg==21
replace dmsouth=0 if  reg==22
replace dmsouth=1 if  reg==23
replace dmsouth=0 if  reg==24
replace dmsouth=0 if  reg==25
replace dmsouth=0 if  reg==26
label var dmsouth "Region -- Dummy -- Southern Province"

gen region=reg+11
label var region "Region"

gen dmaszmid=size==2
label var dmaszmid "Firm Size -- Dummy -- Medium"

gen dmaszlar=size==3
label var dmaszlar "Firm Size -- Dummy -- Large"

replace intcode=intcode+2009000

keep idquest m2 countryn yearsurv weight dmbs* dmsc* dmownfor dmexport lage prdwork wgavprodskus wgavprodunus dmreticent retcount dmretnotund dmreticentgood dmreticent10good retcountgood avdmreticentgoodloo avdmreticent10goodloo avretcountgoodloo dmmngmal dmmngage0030 dmmngage3145 dmmngage4655 dmmngage5600 dmmngedsec dmmngedtert dmsouth region dmaszmid dmaszlar percunion region retcount* avretcount* industry reg screensi zone multi dmret* dmnonret* intcode


******Combine the two data files

append using "C:\Nigeria Wages\Nigeria Wages Firm Level Data TEMP.dta"

******Create additional variables

*****Year Dummy

gen dmyear2009=yearsurv==2009
label var dmyear2009 "Year -- Dummy - Interview in 2009"

*****Dependent Variables

gen ltcwgavprodskus=log(wgavprodskus)
label var ltcwgavprodskus "Log of Wages - Average monthly wages for skilled production workers in US$"
 
gen ltcwgavprodunus=log(wgavprodunus)
label var ltcwgavprodunus "Log of Wages - Average monthly wages for skilled production workers in US$"
 
gen lpcsworker=log(prdwork)
label var lpcsworker "Productivity - Per worker labor costs in US$ (outliers dropped)"

save "C:\Nigeria Wages\Nigeria Wages Firm Level Data TEMP.dta", replace

**********************Setup worker level data

****Load Data

use "C:\Nigeria Wages\employees_nigeria_2009.dta", clear
gen yearsurv=2009
append using "C:\Nigeria Wages\employees_nigeria_2007.dta" 
replace yearsurv=2007 if yearsurv==.

****Deal with data

keep idquest yearsurv country countryname m1_* m2_* m2x_* m3a1_* m3a2_* m3b_* m4a_* m4b* m5* m6* m7* m8* m9* m10* m11* m12* m13* m14* m15* m16* m17* m18* m19* m20* m21* m22* m23* m24* m25* m26* m27* m28* m29*  m30* m31* m32* m33* m34* m35* m36* m37* m38* m39*  m40* m41*

rename m1_10 m1_010
rename m2_10 m2_010
rename m2x_10 m2x_010
rename m3a1_10 m3a1_010
rename m3a2_10 m3a2_010
rename m3b_10 m3b_010
rename m4a_10 m4a_010
rename m4b_10 m4b_010
rename m5a_10 m5a_010
rename m5b_10 m5b_010
rename m6_10 m6_010
rename m7_10 m7_010
rename m8_10 m8_010
rename m9_10 m9_010
rename m10_10 m10_010
rename m11a1_10 m11a1_010
rename m11a2_10 m11a2_010
rename m11b1_10 m11b1_010
rename m11b2_10 m11b2_010
rename m12_10 m12_010
rename m13a1_10 m13a1_010
rename m13a2_10 m13a2_010
rename m14_10 m14_010
rename m15a1_10 m15a1_010
rename m15a2_10 m15a2_010
rename m15b1_10 m15b1_010
rename m15b2_10 m15b2_010
rename m16_10 m16_010
rename m16x_10 m16x_010
rename m17_10 m17_010
rename m18_10 m18_010
rename m19_10 m19_010
rename m20_10 m20_010
rename m21_10 m21_010
rename m22_10 m22_010
rename m23_10 m23_010
rename m24_10 m24_010
rename m25_10 m25_010
rename m25x_10 m25x_010
rename m26_10 m26_010
rename m27_10 m27_010
rename m28_10 m28_010
rename m29_10 m29_010
rename m29x_10 m29x_010
rename m30_10 m30_010
rename m30x_10 m30x_010
rename m31_10 m31_010
rename m32_10 m32_010
rename m33_10 m33_010
rename m34_10 m34_010
rename m35_10 m35_010
rename m36x_10 m36x_010
rename m36_10 m36_010
rename m37_10 m37_010
rename m38_10 m38_010
rename m39_10 m39_010
rename m38x_10 m38x_010
rename m40_10 m40_010
rename m41_10 m41_010


****reshape

reshape long m1_0 m2_0 m2x_0 m3a1_0 m3a2_0 m3b_0 m4a_0 m4b_0 m5a_0 m5b_0 m6_0 m7_0 m8_0 m9_0 m10_0 m11a1_0 m11a2_0 m11b1_0 m11b2_0 m12_0 m13a1_0 m13a2_0 m14_0 m15a1_0 m15a2_0 m15b1_0 m15b2_0  m16_0 m16x_0 m17_0 m18_0 m19_0 m20_0 m21_0 m22_0 m23_0 m24_0 m25_0 m25x_0 m26_0 m27_0 m28_0 m29_0 m29x_0 m30_0 m30x_0  m31_0 m32_0 m33_0 m34_0 m35_0 m36x_0 m36_0 m37_0 m38_0 m39_0 m38x_0  m40_0 m41_0 ,   i(idquest) j(worker)

rename m1_0 m1
rename m2_0 m2
rename m2x_0 m2x
rename m3a1_0 m3a1
rename m3a2_0 m3a2
rename m4a_0 m4a
rename m4b_0 m4b
rename m5a_0 m5a
rename m5b_0 m5b
rename m6_0 m6
rename m7_0 m7
rename m8_0 m8
rename m9_0 m9
rename m10_0 m10
rename m11a1_0 m11a1
rename m11a2_0 m11a2
rename m11b1_0 m11b1
rename m11b2_0 m11b2
rename m12_0 m12
rename m13a1_0 m13a1
rename m13a2_0 m13a2
rename m14_0 m14
rename m15a1_0 m15a1
rename m15a2_0 m15a2
rename m15b1_0 m15b1
rename m15b2_0 m15b2
rename m16_0 m16
rename m16x_0 m16x
rename m17_0 m17
rename m18_0 m18
rename m19_0 m19
rename m20_0 m20
rename m21_0 m21
rename m22_0 m22
rename m23_0 m23
rename m24_0 m24
rename m25_0 m25
rename m25x_0 m25x
rename m26_0 m26
rename m27_0 m27
rename m28_0 m28
rename m29_0 m29
rename m29x_0 m29x
rename m30_0 m30
rename m30x_0 m30x
rename m31_0 m31
rename m32_0 m32
rename m33_0 m33
rename m34_0 m34
rename m35_0 m35
rename m36_0 m36
rename m36x_0 m36x
rename m37_0 m37
rename m38_0 m38
rename m38x_0 m38x
rename m39_0 m39
rename m40_0 m40
rename m41_0 m41

gen ccdefl=. 
replace ccdefl=223.55/160.77 if yearsurv==2009
replace ccdefl=192.215377239075/160.77 if yearsurv==2007
label var ccdefl "Country control - Number - GDP Deflator (one year lagged from survey)"

****Calculate wages

gen annwage=.
replace annwage=m11a2*26 if m11a1==7
replace annwage=m11a2 if m11a1==5
replace annwage=m11a2*12 if m11a1==4
replace annwage=m11a2*52 if m11a1==3
replace annwage=m11a2*52*5 if m11a1==2
replace annwage=annwage/ccdefl
label var annwage "Annual wage"

gen lannwage=log(annwage)
label var lannwage "Log of Annual wage"

gen annhours=m7*52 if m7>0
label var annhours "Annual hours worked"

gen lannhours=log(annhours)
label var lannhours "Log of hours worked"

replace m17=. if m17<0
replace m13a1=. if m13a1<0
replace m13a2=. if m13a2<0

gen experience=m17+m13a1
label var experience "Experience"

replace m5a=. if m5a<0

gen education=m5a 
label var education "Education"

gen dmfemale=m1-1 if m1>0
label var dmfemale "Female Dummy"

gen dmunion=2-m8 if m8==1|m8==2
label var dmunion "Union Member Dummy"

gen dmtrain=m18~=5 if m18==1|m18==2|m18==3|m18==4|m18==5
label var dmunion "Worker has received training dummy"

gen dmjobprop=m9==1 if m9>0&m9~=.
label var dmjobprop "Worker is proprietor"

gen dmjobman=m9==2 if m9>0&m9~=.
label var dmjobman "Worker is manager"

gen dmjobprof=m9==3|m9==4 if m9>0&m9~=.
label var dmjobprof "Worker is professional"

gen dmjobskill=m9==5|m9==6|m9==7 if m9>0&m9~=.
label var dmjobskill "Worker is skilled worker"

gen dmjobunsk=m9==8 if m9>0&m9~=.
label var dmjobunsk "Worker is unskilled worker"

gen dmjobnprod=m9==9|m9==10|m9==11 if m9>0&m9~=.
label var dmjobnprod "Worker is skilled worker"

merge n:1 idquest using "C:\Nigeria Wages\Nigeria Wages Firm Level Data TEMP.dta"

drop if _merge==2

tab region, gen(dmrg)

gen dmyear2007=yearsurv==2007

save "C:\Nigeria Wages\Nigeria Wages Worker Level Data.dta", replace

*****************Setup worker-level variables for firm level data

****Load Data

use "C:\Nigeria Wages\Nigeria Wages Worker Level Data.dta", clear

collapse lannwage, by(idquest)

save "C:\Nigeria Wages\Nigeria ave wages (all).dta", replace

****Load Data

use "C:\Nigeria Wages\Nigeria Wages Worker Level Data.dta", clear

keep if dmjobunsk==1

collapse lannwage, by(idquest)

rename lannwage lannwageunsk

merge 1:1 idquest using "C:\Nigeria Wages\Nigeria ave wages (all).dta"

drop _merge

save "C:\Nigeria Wages\Nigeria ave wages (all).dta", replace

****Load Data

use "C:\Nigeria Wages\Nigeria Wages Worker Level Data.dta", clear

keep if dmjobskill==1

collapse lannwage, by(idquest)

rename lannwage lannwageskil

merge 1:1 idquest using "C:\Nigeria Wages\Nigeria ave wages (all).dta"

drop _merge

save "C:\Nigeria Wages\Nigeria ave wages (all).dta", replace

*********Load Data

clear all

use "C:\Nigeria Wages\Nigeria Wages Firm Level Data TEMP.dta"

merge 1:1 idquest using "C:\Nigeria Wages\Nigeria ave wages (all).dta"

save "C:\Nigeria Wages\Nigeria Wages Firm Level Data.dta", replace
